<?php
/*
Plugin Name: WordPress Video & Audio Streaming SVOD, AVOD
Plugin URI: https://s3bubble.com
Description: Amazon Web Services (AWS), Roku, FireTV, Video Streaming
Version: 6.6
Author: S3Bubble
Author URI: https://s3bubble.com
Text Domain: s3bubble-amazon-web-services-oembed-media-streaming-support
Domain Path: /languages
License: GPL2 
*/
 
/*  Copyright YEAR  S3Bubble  (email : support@s3bubble.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/ 

// Exit if accessed directly.
defined('ABSPATH') || exit;

if (!class_exists("s3bubble_oembed")) {

	class s3bubble_oembed {
		
		// Set the version
		public  $version = 143;  

		/*
		 * Constructor method to intiat the class
		 * @author s3bubble
		 * @params none
		 */
		public function  __construct(){ 

			/*
			 * Run the add admin menu class
			 * @author s3bubble
			 * @params none
			 */ 
			add_action( 'admin_menu', array( $this, 's3bubble_oembed_admin_menu' ));

			/*
			 * Add css to the header of the document
			 * @author s3bubble
			 * @params none
			 */ 
			add_action( 'wp_enqueue_scripts', array( $this, 's3bubble_oembed_scripts' ), 12 );

			/*
			 * Add javascript to the frontend footer connects to wp_footer
			 * @author s3bubble
			 * @params none
			 */ 
			add_action( 'admin_enqueue_scripts', array( $this, 's3bubble_oembed_admin_scripts' ) );
			
			/*
			 * Setup website connection
			 */
			add_action( 'init', array( $this, 's3bubble_website_connection' ));

			/*
			 * Oembed support fix
			 */
			add_action( 'init', array( $this, 's3bubble_oembed_iframes' ));

			/*
			 * Tiny mce button for the plugin
			 * @author s3bubble
			 * @params none
			 */
			add_action( 'init', array( $this, 's3bubble_oembed_buttons' ) );

			/*
			 * Setup shortcodes for the plugin
			 * @author s3bubble
			 * @params none
			 */ 
			add_shortcode( 's3bubble', array( $this, 's3bubble_aws_self_hosted' ) );

			/*
			 * Load the languages file
			 * @author s3bubble
			 * @params none
			 */ 
			add_action( 'plugins_loaded', array( $this, 's3bubble_amazon_web_services_oembed_media_streaming_support_textdomain' ) );

			/*
			 * Set the DRM token
			 * @author s3bubble
			 * @params none
			 */
			add_action('wp_ajax_s3bubble_oembed_set_cookie', array( $this, 's3bubble_oembed_set_cookie' )); 
			add_action('wp_ajax_nopriv_s3bubble_oembed_set_cookie', array( $this, 's3bubble_oembed_set_cookie' ));

			/*
			 * Get the DRM token
			 * @author s3bubble
			 * @params none
			 */
			add_action('wp_ajax_s3bubble_proxy', array( $this, 's3bubble_oembed_proxy_token' )); 
			add_action('wp_ajax_nopriv_s3bubble_proxy', array( $this, 's3bubble_oembed_proxy_token' ));
			add_action('wp_ajax_s3bubble_proxy_token', array( $this, 's3bubble_oembed_proxy_token' )); 
			add_action('wp_ajax_nopriv_s3bubble_proxy_token', array( $this, 's3bubble_oembed_proxy_token' ));

			/*
			 * Admin notices
			 * @author s3bubble
			 * @params none
			 */
			add_action( 'admin_init', array( $this, 's3bubble_oembed_check_installation_date_exists' ) );
			add_action( 'admin_init', array( $this, 's3bubble_oembed_check_installation_date' ) );
			add_action( 'admin_init', array( $this, 's3bubble_oembed_set_no_bug' ) );

		}

		/**
		* Check date on admin initiation and add to admin notice if it was over 10 days ago.
		* @return null
		*/
		function s3bubble_oembed_check_installation_date_exists() {

			if(!get_option('s3bubble_oembed_activation_date')){

				$now = strtotime( "now" );

			    add_option( 's3bubble_oembed_activation_date', $now );

			}

		}

		/**
		* Check date on admin initiation and add to admin notice if it was over 10 days ago.
		* @return null
		*/
		function s3bubble_oembed_check_installation_date() {

		    $install_date = get_option( 's3bubble_oembed_activation_date' );

		    $nobug = get_option('s3bubble_oembed_no_bug');

		    if (!$nobug) {

			    $past_date = strtotime( '-12 days' );

			    if ( $past_date >= $install_date ) {

			        add_action( 'admin_notices', array( $this, 's3bubble_oembed_display_admin_notice' ) );

			    }

			}

		}

		/**
		* Display Admin Notice, asking for a review
		* @return null
		*/
		function s3bubble_oembed_display_admin_notice() {

		    // Review URL - Change to the URL of your plugin on WordPress.org
		    $reviewurl = 'https://wordpress.org/support/plugin/s3bubble-amazon-web-services-oembed-media-streaming-support/reviews/?rate=5#new-post';

		    $nobugurl = get_admin_url() . '?s3bubble_oembed_review_dismiss=1';

		    echo '<div class="notice notice-info s3bubble-oembed-notice"><img height="60" src="https://ps.w.org/s3bubble-amazon-web-services-oembed-media-streaming-support/assets/icon-128x128.jpg" /><p>'; 

		    	printf( __( "<b>Help Development!</b> We have noticed that you have been using <b>S3Bubble AWS Protected DRM Video Streaming‎</b> for some time. We hope you love it, and we would really appreciate it if you would give us a 5 stars rating! <a href='%s' target='_blank'>Leave A Review</a> | <a href='%s'>Leave Me Alone</a>" ), $reviewurl, $nobugurl ); 

		    echo "</p></div>";
		}

		/**
		* Set the plugin to no longer bug users if user asks not to be.
		* @return null
		*/
		function s3bubble_oembed_set_no_bug() {

		    $nobug = "";

		    if ( isset( $_GET['s3bubble_oembed_review_dismiss'] ) ) {

		        $nobug = esc_attr( $_GET['s3bubble_oembed_review_dismiss'] );
		    
		    }

		    if ( 1 == $nobug ) {

		        add_option( 's3bubble_oembed_no_bug', TRUE );

		    }

		} 

		/*
		 * Loads the path to languages folder
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_amazon_web_services_oembed_media_streaming_support_textdomain() {
		 
		    load_plugin_textdomain( 's3bubble-amazon-web-services-oembed-media-streaming-support', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
		
		}


		/*
		 * Create a connected website option
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_website_connection(){

			if(isset($_SERVER['HTTP_HOST'])){

				$host = (isset($_SERVER['REMOTE_ADDR']) && $_SERVER['REMOTE_ADDR'] == "127.0.0.1") ? "localhost" : $_SERVER['HTTP_HOST'];
		
				$host = preg_replace('#^www\.(.+\.)#i', '$1', $host); // remove the www
		
				update_option("s3bubble_oembed_connected_website", $host);

			}

		}

		/*
		 * Self hosted code
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_aws_self_hosted($atts){

			// Extract the vars from the shortcode
			extract( shortcode_atts( array(
				'code'   => '', // Playlists
				'codes'   => '', // Media
				'source'   => '', // source data
				'options'   => '', // Options
				'meta'   => '', // meta data
				'brand'   => '', // brand data
				'modal'   => '', // modal data
				'popit'  => '', // popit data
				'stream'   => '', // Stream
				'type' => 'video',
				'media' => 'video'
			), $atts, 's3bubble' ) );

			// Make sure its unique
			$id = uniqid();

			if(!empty($stream)){
				$type = "stream";
			}

			if(!empty($code)){
				return '<div id="s3bubble-' . $id . '" class="s3bubble-playlist" data-setup=\'{"code": "' . $code . '","type": "' . $type . '"}\'></div>';
			}

			// Check for multiple codes
			if(strpos($codes, ',') !== false) {
				$codes = explode(",", $codes);
				$codes = json_encode($codes);
			}else{
				$codes = json_encode(array($codes));
			}

			// Check for the popit plugin
			if (array_key_exists("popit",$atts)){
				$popit = ',"popit": {' . $popit . '}';
			}

			switch ($type) {
				case 'video':
					// Video single
					return '<div id="s3bubble-' . $id . '" class="s3bubble" data-setup=\'{"codes": ' . $codes . ',"source": {' . $source . '},"options": {' . $options . '},"meta": {' . $meta . '},"brand": {' . $brand . '}' . $popit . '}\'></div>';
					break;
				case 'audio':
					// Audio single
					return '<div id="s3bubble-' . $id . '" class="s3bubble-audio" data-setup=\'{"codes": ' . $codes . ',"source": {' . $source . '},"options": {' . $options . '},"meta": {' . $meta . '},"brand": {' . $brand . '}' . $popit . '}\'></div>';
					break;
				case 'service':
				    // Youtube links
					return '<div id="s3bubble-' . $id . '" class="s3bubble-service" data-setup=\'{"codes": ' . $codes . ',"source": {' . $source . '},"options": {' . $options . '},"meta": {' . $meta . '},"brand": {' . $brand . '}' . $popit . '}\'></div>';
					break;
				case 'stream':
					// This needs to be different 
					return '<div id="s3bubble-' . $id . '" class="s3bubble-live" data-setup=\'{"stream": "' . $stream . '","source": {' . $source . '},"options": {' . $options . '},"meta": {' . $meta . '},"brand": {' . $brand . '}' . $popit . '}\'></div>';
					break;
				case 'modal':
					// Modal popup
					return '<div id="s3bubble-' . $id . '" class="s3bubble-modal" data-setup=\'{"codes": ' . $codes . ',"source": {' . $source . '},"options": {' . $options . '},"meta": {' . $meta . '},"brand": {' . $brand . '},"modal": {' . $modal . '}}\'></div>';
					break;
				default:
					
					break;
			}

		}

		/*
		 * Add default option to database
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_oembed_iframes(){

			// Audio progressive
			wp_embed_register_handler( 
		        's3bubble-audio-progressive', 
		        '#https://media.s3bubble\.com/embed/aprogressive/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_audio_oembed_progressive_embed_handler' ) 
		    );
		    
		    // Audio hls
			wp_embed_register_handler( 
		        's3bubble-audio-hls', 
		        '#https://media.s3bubble\.com/embed/ahls/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_audio_oembed_hls_embed_handler' ) 
		    );

			// Video progressive
		    wp_embed_register_handler( 
		        's3bubble-video-progressive', 
		        '#https://media.s3bubble\.com/embed/progressive/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_video_oembed_progressive_embed_handler' )
		    );

		    // 360 Degree Video pano
		    wp_embed_register_handler( 
		        's3bubble-video-pano', 
		        '#https://media.s3bubble\.com/embed/pano/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_video_oembed_pano_embed_handler' )
		    );

			// Video hls
		    wp_embed_register_handler( 
		        's3bubble-video-hls', 
		        '#https://media.s3bubble\.com/embed/hls/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_video_oembed_hls_embed_handler' )
		    );

		    // Video hls playlist
		    wp_embed_register_handler( 
		        's3bubble-video-playlist', 
		        '#https://media.s3bubble\.com/embed/playlist/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_video_oembed_playlist_embed_handler' )
		    );

		    // Audio hls playlist
		    wp_embed_register_handler( 
		        's3bubble-audio-playlist', 
		        '#https://media.s3bubble\.com/embed/aplaylist/id/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_audio_oembed_playlist_embed_handler' )
		    );

		    // Live streaming
		    wp_embed_register_handler( 
		        's3bubble-video-live-streaming', 
		        '#https://media.s3bubble\.com/embed/live/username/([a-zA-Z0-9_-]+)$#i',   // <-- Adjust this to your needs!
		        array( $this, 's3bubble_video_oembed_live_embed_handler' )
		    );

		}

		/*
		 * Adds progressive oembed audio iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_audio_oembed_progressive_embed_handler( $matches, $attr, $url, $rawattr )
		{
		
		    $embed = sprintf(
		        '<iframe class="s3bubble-audio-oembed-iframes" src="https://media.s3bubble.com/embed/aprogressive/id/%1$s" height="160" frameborder="0" allowfullscreen></iframe>',
		        esc_attr( $matches[1] )
		    );
		
		    return apply_filters( 's3bubble_audio_oembed_progressive_embed_handler', $embed, $matches, $attr, $url, $rawattr );
		
		}

		/*
		 * Adds adaptive bitrate oembed audio iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_audio_oembed_hls_embed_handler( $matches, $attr, $url, $rawattr )
		{
		
		    $embed = sprintf(
		        '<iframe class="s3bubble-audio-oembed-iframes" src="https://media.s3bubble.com/embed/ahls/id/%1$s" height="160" frameborder="0" allowfullscreen></iframe>',
		        esc_attr( $matches[1] )
		    );
		
		    return apply_filters( 's3bubble_audio_oembed_hls_embed_handler', $embed, $matches, $attr, $url, $rawattr );
		
		}
        
        /*
		 * Adds progressive oembed video iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_video_oembed_progressive_embed_handler( $matches, $attr, $url, $rawattr )
		{

			$id = uniqid();

			if(get_option( 's3bubble_selfhosted_switch' )){

				return '<div id="s3bubble-' . $id . '" class="s3bubble" data-setup=\'{"codes": ["' . esc_attr( $matches[1] ) . '"]}\'></div>';

			}else{

				$embed = sprintf(
			        '<iframe height="360" class="s3bubble-video-oembed-iframes" src="https://media.s3bubble.com/embed/progressive/id/%1$s" frameborder="0" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true"></iframe>',
			        esc_attr( $matches[1] )
			    );
		
			    return apply_filters( 's3bubble_video_oembed_progressive_embed_handler', $embed, $matches, $attr, $url, $rawattr );

			}

		}

		/*
		 * Adds pano 360 degress oembed video iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_video_oembed_pano_embed_handler( $matches, $attr, $url, $rawattr )
		{
		    $embed = sprintf(
		        '<iframe height="360" class="s3bubble-video-oembed-iframes" src="https://media.s3bubble.com/embed/pano/id/%1$s" frameborder="0" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true"></iframe>',
		        esc_attr( $matches[1] )
		    );
		
		    return apply_filters( 's3bubble_video_oembed_pano_embed_handler', $embed, $matches, $attr, $url, $rawattr );
		
		}
        
        /*
		 * Adds adaptive bitrate oembed video iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_video_oembed_hls_embed_handler( $matches, $attr, $url, $rawattr )
		{

			// Make sure its unique
			$id = uniqid();

			if(get_option( 's3bubble_selfhosted_switch' )){

				return '<div id="s3bubble-' . $id . '" class="s3bubble" data-setup=\'{"codes": ["' . esc_attr( $matches[1] ) . '"]}\'></div>';

			}else{

				$embed = sprintf(
			        '<iframe height="360" class="s3bubble-video-oembed-iframes" src="https://media.s3bubble.com/embed/hls/id/%1$s" frameborder="0" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true"></iframe>',
			        esc_attr( $matches[1] )
			    );
		
			    return apply_filters( 's3bubble_video_oembed_hls_embed_handler', $embed, $matches, $attr, $url, $rawattr );

			}
		    
		}

		/*
		 * Adds adaptive bitrate oembed video playlist iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_video_oembed_playlist_embed_handler( $matches, $attr, $url, $rawattr )
		{
		    $embed = sprintf(
		        '<iframe height="360" class="s3bubble-video-oembed-iframes" src="https://media.s3bubble.com/embed/playlist/id/%1$s" frameborder="0" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true"></iframe>',
		        esc_attr( $matches[1] )
		    );
		
		    return apply_filters( 's3bubble_video_oembed_playlist_embed_handler', $embed, $matches, $attr, $url, $rawattr );
		
		}

		/*
		 * Adds adaptive bitrate oembed audio playlist iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_audio_oembed_playlist_embed_handler( $matches, $attr, $url, $rawattr )
		{
		    $embed = sprintf(
		        '<iframe height="290" class="s3bubble-audio-oembed-iframes" src="https://media.s3bubble.com/embed/aplaylist/id/%1$s" frameborder="0" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true"></iframe>',
		        esc_attr( $matches[1] )
		    );
		
		    return apply_filters( 's3bubble_audio_oembed_playlist_embed_handler', $embed, $matches, $attr, $url, $rawattr );
		
		}

		/*
		 * Adds live streaming iframe support
		 * @author s3bubble
		 * @params none
		 */ 
		function s3bubble_video_oembed_live_embed_handler( $matches, $attr, $url, $rawattr )
		{
		    $embed = sprintf(
		        '<iframe height="360" class="s3bubble-video-oembed-iframes" src="https://media.s3bubble.com/embed/live/username/%1$s" frameborder="0" webkitAllowFullScreen="true" mozallowfullscreen="true" allowFullScreen="true"></iframe>',
		        esc_attr( $matches[1] )
		    );
		    
		    return apply_filters( 's3bubble_video_oembed_live_embed_handler', $embed, $matches, $attr, $url, $rawattr );
		
		}

		function register_s3bubble_aws_self_hosted_settings() {
		
			register_setting( 's3bubble-aws-self-hosted-plugin-settings-group', 's3bubble_selfhosted_switch' );
		
		}

		/*
		* Adds the menu item to the wordpress admin
		* @author s3bubble
		* @none
		*/ 
        function s3bubble_oembed_admin_menu(){

			add_menu_page( 's3bubble_oembed', 'S3Bubble OTT', 'administrator', 's3bubble_oembed', array($this, 's3bubble_oembed_admin'), 'dashicons-video-alt3', 10);

			add_action( 'admin_init', array($this, 'register_s3bubble_aws_self_hosted_settings') );

    	}

    	/*
		* Add css to wordpress admin to run colourpicker
		* @author s3bubble
		* @none
		*/ 
		function s3bubble_oembed_admin_scripts(){
			
			$s3bubble_oembed_connected_website = get_option("s3bubble_oembed_connected_website");
			
			wp_enqueue_style( 's3bubble-oembed-admin-css', plugins_url('/dist/css/admin.min.css', __FILE__), array(), $this->version );
			
			wp_enqueue_style( 's3bubble-oembed-chosen-css', plugins_url('/dist/css/chosen.min.css', __FILE__), array(), $this->version );
			
			wp_enqueue_style( 's3bubble-oembed-sweet-css', plugins_url('/dist/css/sweetalert.min.css', __FILE__), array(), $this->version );

			wp_enqueue_script( 'buttons-github-js', 'https://buttons.github.io/buttons.js', array(),  $this->version, false );
			
			wp_enqueue_script( 's3bubble-oembed-chosen-js', plugins_url('/dist/js/chosen.jquery.min.js',__FILE__ ), array( 'jquery' ),  $this->version, true );
			
			wp_enqueue_script( 's3bubble-oembed-sweetalert-js', plugins_url('/dist/js/sweetalert.min.js',__FILE__ ), array( 'jquery' ),  $this->version, true );
			
			wp_localize_script('s3bubble-oembed-sweetalert-js', 's3bubble_oembed_uid', array(
				's3website' => (!empty($s3bubble_oembed_connected_website) ? $s3bubble_oembed_connected_website : ""),
				's3bubbleSelfHosted' => get_option( 's3bubble_selfhosted_switch' ) ? "true" : "false"
			));

		}
		
		/*
		* Add css ties into wp_head() function
		* @author s3bubble
		* @params none
        */ 
		function s3bubble_oembed_scripts(){
			
			wp_enqueue_style('s3bubble-oembed-css', plugins_url('/dist/css/styles.min.css',__FILE__ ), array(),  $this->version );

			wp_enqueue_script( 's3bubble-oembed-js', plugins_url('/dist/js/scripts.min.js',__FILE__ ), array( 'jquery' ),  $this->version, true );

			wp_enqueue_style('s3bubble-hosted-cdn', plugins_url('/dist/css/s3bubble.min.css',__FILE__ ), array(), $this->version);

        	wp_enqueue_script('s3bubble-hosted-cdn', plugins_url('/dist/js/s3bubble.min.js',__FILE__ ), array(), $this->version, true);

        	wp_localize_script( 's3bubble-hosted-cdn', 's3bubble_oembed', array(
				'ajax' => admin_url( 'admin-ajax.php' ),
				'nonce' => wp_create_nonce('ajax-nonce')
			));

		}

		/*
		* Sets up tiny mce plugins
		* @author s3bubble
		* @none
		*/ 
		function s3bubble_oembed_buttons() {
		
			if ( current_user_can( 'manage_options' ) )  {
		
				add_filter( 'mce_external_plugins', array( $this, 's3bubble_oembed_add_buttons' ) ); 
		
				add_filter( 'mce_buttons', array( $this, 's3bubble_oembed_register_buttons' ) );
		
			} 
		
		}
		 
		/*
		* Adds the menu item to the tiny mce
		* @author s3bubble
		* @none
		*/ 
		function s3bubble_oembed_add_buttons( $plugin_array ) {
		
		    $plugin_array['S3bubbleOembed'] = plugins_url('/dist/js/tinymce.min.js',__FILE__);
		
		    return $plugin_array;
		
		}
		
		/*
		* Registers the amount of buttons
		* @author s3bubble
		* @none
		*/ 
		function s3bubble_oembed_register_buttons( $buttons ) {
		    
		    array_push( $buttons, 's3bubble_oembed_global_shortcode' ); 
		    
		    return $buttons;

		}
		 
    	/*
		* Add javascript to the footer connect to wp_footer()
		* @author s3bubble
		* @none
		*/ 
		function s3bubble_oembed_admin(){ 

			$alert = "";

			if(isset($_SERVER['HTTP_HOST'])){

				$host = (isset($_SERVER['REMOTE_ADDR']) && $_SERVER['REMOTE_ADDR'] == "127.0.0.1") ? "localhost" : $_SERVER['HTTP_HOST'];
				$host = preg_replace('#^www\.(.+\.)#i', '$1', $host); // remove the www
				update_option("s3bubble_oembed_connected_website", $host);

			}else{

				$alert = '<div class="error"><p>We could not get your website address please contact support@s3bubble.com</p></div>';
			
			}

		?>

		<div class="wrap">
			<h2><?php _e( 'WordPress Media Streaming', 's3bubble-amazon-web-services-oembed-media-streaming-support' ); ?></h2>
			<?php echo $alert; ?>
			<div class="metabox-holder">
				<div id="post-body">
					<div id="post-body-content">
						<div class="postbox"> 
							<h3 class="hndle"><?php _e( 'Please Watch Our Setup Videos', 's3bubble-amazon-web-services-oembed-media-streaming-support' ); ?></h3>
							<div class="inside s3bubble-admin-inside">

								<div class="s3bubble-admin-video-wrapper">
									
									<div style="position: relative;padding-bottom: 56.25%;"><iframe style="position: absolute;top: 0;left: 0;width: 100%;height: 100%;" src="https://www.youtube.com/embed/QcHNTZH2QHQ" frameborder="0" allowfullscreen></iframe></div> 	

								</div>

								<div class="s3bubble-admin-video-wrapper">

									<h3 class="hndle"><?php echo __( 'DRM Secure Proxy Url', 's3bubble-amazon-web-services-oembed-media-streaming-support' ); ?></h3>
									
									<div class="inside">
										<pre class="s3bubble-pre"><?php echo admin_url( 'admin-ajax.php' ); ?>?action=s3bubble_proxy</pre>
										<p><b>Use the url above to prevent your media from being easily downloaded.</b></p>
									</div>

									<div class="inside">
										<p>To get started with S3Bubble you need to sign up for an account you can then connect your website and start creating your players.</p>
										<a class="button button-primary button-hero" href="https://s3bubble.com" target="_blank"><?php echo __( 'Sign Up', 's3bubble-amazon-web-services-oembed-media-streaming-support' ); ?></a>
									</div> 

									<div class="inside">
										<p>If you would like to use Woocommerce to monetize your content via PPV or SVOD please download our DRM plugin specifically setup for this.</p>
										<a class="button button-primary button-hero" href="https://en-gb.wordpress.org/plugins/drm-protected-video-streaming/" target="_blank"><?php echo __( 'DRM Plugin', 's3bubble-amazon-web-services-oembed-media-streaming-support' ); ?></a>
									</div> 

								</div>
							
							</div><!-- .inside -->

						</div>

					</div> <!-- #post-body-content -->
				</div> <!-- #post-body -->
			</div> <!-- .metabox-holder --> 
		</div> <!-- .wrap -->
		<?php	
       }

       /*
		 * Get the DRM token
		 * @author s3bubble
		 * @params none
		 */
		function s3bubble_oembed_set_cookie(){

			// Check for nonce security
		    $nonce = $_POST['nonce'];

		    if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) ){

		        wp_send_json(array(
			        'status' => false,
			        'message' => __('Verification failed', 's3bubble-amazon-web-services-oembed-media-streaming-support'),
			    ));

		    }

			if(!empty($_POST['name']) && !empty($_POST['token'])){

				if($_POST['name'] == 'wp-mobile-tokenization'){

					set_transient( 'wp-mobile-tokenization', $_POST['token'] );
				
				}else{

					delete_transient('wp-mobile-tokenization');

					setrawcookie($_POST['name'], $_POST['token'], time()+3600, COOKIEPATH, COOKIE_DOMAIN);

				}

				wp_send_json(array(
			        'status' => true,
			        'message' => __('Cookie set', 's3bubble-amazon-web-services-oembed-media-streaming-support'),
			    ));

			}else{

				wp_send_json(array(
			        'status' => false,
			        'message' => __('Cookie failed', 's3bubble-amazon-web-services-oembed-media-streaming-support'),
			    ));

			}

		}


       function s3bubble_oembed_proxy_token(){

       		if(get_transient('wp-mobile-tokenization')){

				$response = wp_remote_post( 'https://s3bubbleapi.com/proxy/token', array(
				    'headers' => array(
				        'Authorization' => get_transient('wp-mobile-tokenization')
				    )
				));

				if ( is_wp_error( $response ) ) {
				    
				    $error_message = $response->get_error_message();

				    echo "Something went wrong: $error_message";

				} else {
				   	
				   	if(isset($response['body'])){

				   		echo $response['body'];

				   	}else{

				   		echo "Authorization failed:";

				   	}

				} 

			}else{

				$key = bin2hex(openssl_random_pseudo_bytes(16));

				echo hex2bin($key);

			}

			die(); // !IMPORTANT

       }


    }

	/*
	* Initiate the class
	* @author s3bubble
	* @none
	*/ 
	$s3bubble_oembed = new s3bubble_oembed();
	
}